@@ -32,7 +32,7 @@ assign_list_class <- function(x, the_class){
   if(!is.null(x)){
     # fix 253
     # make sure its a list of segment_ga4 objects
-    if(class(x) == "list" &&
+    if(inherits(x, "list") &&
        all(unlist(lapply(x, function(y) is(y, the_class))))){
       class(x) <- the_class
     } else {
